package com.dzeio.charts

import android.content.Context
import android.graphics.Canvas
import android.graphics.Color
import android.graphics.Paint
import android.graphics.RectF
import android.util.AttributeSet
import android.util.Log
import android.view.MotionEvent
import android.view.View
import com.dzeio.charts.axis.XAxis
import com.dzeio.charts.axis.YAxis
import com.dzeio.charts.components.ChartScroll
import com.dzeio.charts.series.SerieInterface

class ChartView @JvmOverloads constructor(context: Context?, attrs: AttributeSet? = null) :
    View(context, attrs), ChartViewInterface {

    private companion object {
        const val TAG = "Charts/ChartView"
    }

    private val rect = RectF()

    private val debugStrokePaint = Paint().apply {
        style = Paint.Style.STROKE
        strokeWidth = 8f
        color = Color.parseColor("#654321")
    }

    override var debug: Boolean = false

    override val xAxis = XAxis(this)

    override val yAxis = YAxis(this)

    override var series: ArrayList<SerieInterface> = arrayListOf()

    override fun refresh() {
        invalidate()
    }

    override fun onDraw(canvas: Canvas) {

        if (debug) {
            // draw corners
            canvas.drawRect(rect.apply {
                set(8f, 8f, width - 8f, height - 8f)
            }, debugStrokePaint)
        }

        // chart draw rectangle
        rect.apply {
            set(0f, 0f, width.toFloat(), height.toFloat())
        }

        for (serie in series) {
            serie.onDraw(canvas, rect)
        }
        super.onDraw(canvas)
    }

    override fun onTouchEvent(event: MotionEvent): Boolean {
        performClick()
        return scroller.onTouchEvent(event)
    }

    val scroller = ChartScroll(this).apply {
        var lastMovement = 0.0
        setOnChartMoved { movementX, _ ->

            Log.d(TAG, "scrolled: ${(movementX - lastMovement) * (xAxis.increment / 10)}")
            xAxis.x = xAxis.x + (movementX - lastMovement) * (xAxis.increment / 10)
            lastMovement = movementX.toDouble()
            refresh()
        }
//        setOnZoomChanged {
//            Log.d(TAG, "New Zoom: $it")
//            zoom = (it * 1.2).toFloat()
//            refresh()
//        }
    }
}