package com.dzeio.charts.axis

import android.graphics.RectF
import com.dzeio.charts.ChartViewInterface
import com.dzeio.charts.Entry

class XAxis(
    private val view: ChartViewInterface
) : XAxisInterface {
    override var x: Double = 0.0
        set(value) {
            val max = getXMax() - increment * displayCount
            if (value > max) {
                field = max
                return
            }

            val min = getXMin()
            if (value < min) {
                field = min
                return
            }

            field = value
        }
    override var increment: Double = 1.0
    override var displayCount: Int = 10
    override var labelCount: Int = 3

    override fun getPositionOnRect(entry: Entry, rect: RectF): Double {
        return translatePositionToRect(entry.x, rect)
    }

    fun translatePositionToRect(value: Double, rect: RectF): Double {
        val rectItem = rect.width() / displayCount // item size in graph
        return rectItem * value / increment
    }

    override fun getXOffset(rect: RectF): Double {
        return translatePositionToRect(x, rect)
    }

    override fun getXMax(): Double {
        return view.series.maxOf { serie ->
            serie.entries.maxOf { entry -> entry.x }
        }
    }

    override fun getXMin(): Double {
        return view.series.minOf { serie ->
            serie.entries.minOf { entry -> entry.x }
        }
    }


}