package com.dzeio.charts.axis

import android.graphics.Canvas
import android.graphics.Color
import android.graphics.Paint
import android.graphics.RectF
import com.dzeio.charts.ChartViewInterface

class YAxis(
    private val view: ChartViewInterface
) : YAxisInterface {

    override var enabled = false

    override val textLabel = Paint().apply {
        isAntiAlias = true
        color = Color.parseColor("#FC496D")
        textSize = 30f
        textAlign = Paint.Align.RIGHT
    }

    override var labelCount: Int = 3

    private var min: Float? = null
    private var max: Float? = null

    override fun setYMin(yMin: Float?): YAxisInterface {
        min = yMin
        return this
    }

    override fun setYMax(yMax: Float?): YAxisInterface {
        max = yMax
        return this
    }

    override fun getYMax(): Float {
        if (max != null) {
            return max!!
        }
        if (view.series.isEmpty()) {
            return 100f
        }
        return view.series
            .maxOf { serie ->
                if (serie.getDisplayedEntries().isEmpty()) {
                    return@maxOf 0f
                }
                return@maxOf serie.getDisplayedEntries().maxOf { entry -> entry.y }
            }
    }

    override fun getYMin(): Float {
        if (min != null) {
            return min!!
        }
        if (view.series.isEmpty()) {
            return 0f
        }
        return view.series
            .minOf { serie ->
                if (serie.getDisplayedEntries().isEmpty()) {
                    return@minOf 0f
                }
                return@minOf serie.getDisplayedEntries().minOf { entry -> entry.y }
            }
    }

    override fun onDraw(canvas: Canvas, drawLocation: RectF) {
        val min = getYMin()
        val max = getYMax() - min
        val top = drawLocation.top
        val bottom = drawLocation.bottom

        val increment = (bottom - top) / labelCount
        val valueIncrement = (max - min) / labelCount
        for (index in 0 until labelCount) {
            canvas.drawText(
                (valueIncrement * (labelCount + 1)).toString(),
                bottom - (index + 1) * increment,
                drawLocation.right,
                textLabel
            )
        }
        TODO("IDK if it works tbh")
    }
}