package com.dzeio.charts.axis

import android.graphics.Canvas
import android.graphics.Paint
import android.graphics.RectF

sealed interface YAxisInterface {

    /**
     * whether or not this axis is displayed
     */
    var enabled: Boolean

    /**
     * override Y minimum
     *
     * @param yMin is set the min will ba at the value, if null it is calculated
     */
    fun setYMin(yMin: Float?): YAxisInterface

    /**
     * override Y maximum
     *
     * @param yMax is set the max will ba at the value, if null it is calculated
     */
    fun setYMax(yMax: Float?): YAxisInterface

    /**
     * get Y maximum
     *
     * @return the maximum value Y can get (for displayed values)
     */
    fun getYMax(): Float

    /**
     * get Y minimum
     *
     * @return the minimum value Y can get (for displayed values)
     */
    fun getYMin(): Float

    /**
     * get/set the number of label of this Y axis
     *
     * the first/last labels are at the bottom/top of the chart
     */
    var labelCount: Int

    /**
     * text label paint
     */
    val textLabel: Paint

    /**
     * function that draw our legend
     */
    fun onDraw(canvas: Canvas, drawLocation: RectF)
}