package com.dzeio.charts.series

import android.graphics.Canvas
import android.graphics.Color
import android.graphics.Paint
import android.graphics.RectF
import com.dzeio.charts.ChartView

class BarSerie(
    private val view: ChartView
) : BaseSerie(view) {

    private companion object {
        const val TAG = "Charts/BarSerie"
    }

    val barPaint = Paint().apply {
        isAntiAlias = true
        color = Color.parseColor("#123456")
    }

    override fun onDraw(canvas: Canvas, drawableSpace: RectF) {
        val spacing = drawableSpace.width() / view.xAxis.displayCount / 10
        val barWidth = drawableSpace.width() / view.xAxis.displayCount - spacing
        val displayedEntries = getDisplayedEntries()
        val max = view.yAxis.getYMax()
        val min = view.yAxis.getYMin()

//        Log.d(TAG, "${space.left}, ${space.right}")

        for (entry in displayedEntries) {
            // calculated height in percent from 0 to 100
            val height = (1 - entry.y / max) * drawableSpace.height()
            // -1.945763981752553E-21
            // 2.103653925902835E-21
            val posX = view.xAxis.getPositionOnRect(entry, drawableSpace) - view.xAxis.getXOffset(drawableSpace) - canvas.width
//            Log.d(TAG, "gpor = ${view.xAxis.getPositionOnRect(entry, space)}, gxo = ${view.xAxis.getXOffset(space)}")
//            Log.d(TAG, "max = $max, y = ${entry.y}, height = $height")
//            Log.d(TAG, "posX: ${posX / 60 / 60 / 1000}, offsetX = ${view.xAxis.x / (1000 * 60 * 60)}, x = ${entry.x / (1000 * 60 * 60)}, pouet: ${(view.xAxis.x + view.xAxis.displayCount * view.xAxis.increment) / (1000 * 60 * 60)}")

//            Log.d(
//                TAG, """
//                ${posX.toFloat()},
//                $height,
//                ${(posX + barWidth).toFloat()},
//                ${space.bottom}""".trimIndent()
//            )

            canvas.drawRect(
                posX.toFloat(),
                height,
                (posX + barWidth).toFloat(),
                drawableSpace.bottom,
                barPaint
            )

            canvas.drawText(
                entry.y.toString(),
                (posX + barWidth / 2).toFloat(),
                drawableSpace.bottom / 2,
                view.yAxis.textLabel.apply {
                    textAlign = Paint.Align.CENTER

                }
            )
        }
    }
}